version_bump/release
Release records produced and consumed across the pipeline: the previous
release discovered in git, the release about to be made, and the artifacts a
publish / add_channel hook produces.
Types
The most recent release reachable on the current channel, if any.
pub type LastRelease {
LastRelease(
version: String,
git_tag: String,
git_head: String,
channels: List(option.Option(String)),
)
}
Constructors
-
LastRelease( version: String, git_tag: String, git_head: String, channels: List(option.Option(String)), )
The release about to be made.
pub type NextRelease {
NextRelease(
version: String,
type_: semver.ReleaseType,
git_tag: String,
git_head: String,
channel: option.Option(String),
notes: String,
)
}
Constructors
-
NextRelease( version: String, type_: semver.ReleaseType, git_tag: String, git_head: String, channel: option.Option(String), notes: String, )
A release produced by a publish / add_channel hook.
pub type Release {
Release(
name: String,
url: option.Option(String),
version: String,
git_tag: String,
channel: option.Option(String),
plugin_name: String,
)
}
Constructors
-
Release( name: String, url: option.Option(String), version: String, git_tag: String, channel: option.Option(String), plugin_name: String, )